package
Version:
v0.0.0-...-48b49ba
Opens a new window with list of versions in this module.
Published: Aug 6, 2023
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type App struct {
Name string `env-required:"true" yaml:"name" env:"APP_NAME"`
Version string `env-required:"true" yaml:"version" env:"APP_VERSION"`
}
type Config struct {
App `yaml:"app"`
HTTP `yaml:"http"`
Logger `yaml:"logger"`
DB `yaml:"db"`
Redis `yaml:"redis"`
JWT `yaml:"jwt"`
}
type DB struct {
URL string `env-required:"true" yaml:"url" env:"DB_URL"`
}
type HTTP struct {
Port string `env-required:"true" yaml:"port" env:"HTTP_PORT"`
}
type JWT struct {
Secret string `env-required:"true" yaml:"secret" env:"JWT_SECRET"`
Duration int64 `env-required:"true" yaml:"duration" env:"JWT_DURATION"`
}
type Logger struct {
Level string `env-required:"true" yaml:"level" env:"LOG_LEVEL"`
}
type Redis struct {
URL string `env-required:"true" yaml:"url" env:"REDIS_URL"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.